@@ -6,7 +6,7 @@ class AMS():
     def __init__(self, env="test"):
         self.env = env
 
-    def get_addresses(self, blockchain_id, account=1065010, include_balances=False):
+    def get_addresses(self, account, blockchain_id=None, include_balances=False):
         offset = 0
         take = 100
         addresses = []
